@@ -84,7 +84,7 @@ wald_test <- function(...) {
 #' #
 wald_test.drtmle <- function(object, est = c("drtmle"), null = 0,
                              contrast = NULL, ...) {
-  if (class(object) != "drtmle") {
+  if (!inherits(object, "drtmle")) {
     stop("wald_test only works with drtmle objects")
   }
   out <- vector(mode = "list", length = length(est))
@@ -259,7 +259,7 @@ wald_test.adaptive_iptw <- function(object, est = c("iptw_tmle"), null = 0,
   if (any(est == "iptw")) {
     stop("Theory does not support inference for naive IPTW with super learner.")
   }
-  if (class(object) != "adaptive_iptw") {
+  if (!inherits(object, "adaptive_iptw")) {
     stop("ci only works with adaptive_iptw objects")
   }
   out <- vector(mode = "list", length = length(est))
