@@ -99,8 +99,8 @@ test_that("drtmle executes as expected with stratify = TRUE", {
     W = W, A = A, Y = Y,
     family = gaussian(),
     stratify = TRUE,
-    SL_Q = c("SL.glm", "SL.step"),
-    SL_g = c("SL.glm", "SL.step"),
+    SL_Q = c("SL.glm", "SL.mean"),
+    SL_g = c("SL.glm", "SL.mean"),
     SL_Qr = c("SL.glm", "SL.mean"),
     SL_gr = c("SL.glm", "SL.mean"),
     guard = c("Q", "g"),
@@ -123,8 +123,8 @@ test_that("drtmle executes as expected with stratify = TRUE", {
     W = W, A = A, Y = Y,
     family = gaussian(),
     stratify = TRUE,
-    SL_Q = c("SL.glm", "SL.step"),
-    SL_g = c("SL.glm", "SL.step"),
+    SL_Q = c("SL.glm", "SL.mean"),
+    SL_g = c("SL.glm", "SL.mean"),
     SL_Qr = c("SL.glm", "SL.mean"),
     SL_gr = c("SL.glm", "SL.mean"),
     guard = c("Q", "g"),
@@ -276,8 +276,8 @@ test_that("drtmle executes as expected with stratify = FALSE", {
     W = W, A = A, Y = Y,
     family = gaussian(),
     stratify = FALSE,
-    SL_Q = c("SL.glm", "SL.step"),
-    SL_g = c("SL.glm", "SL.step"),
+    SL_Q = c("SL.glm", "SL.mean"),
+    SL_g = c("SL.glm", "SL.mean"),
     SL_Qr = c("SL.glm", "SL.mean"),
     SL_gr = c("SL.glm", "SL.mean"),
     guard = c("Q", "g"),
@@ -300,8 +300,8 @@ test_that("drtmle executes as expected with stratify = FALSE", {
     W = W, A = A, Y = Y,
     family = gaussian(),
     stratify = FALSE,
-    SL_Q = c("SL.glm", "SL.step"),
-    SL_g = c("SL.glm", "SL.step"),
+    SL_Q = c("SL.glm", "SL.mean"),
+    SL_g = c("SL.glm", "SL.mean"),
     SL_Qr = c("SL.glm", "SL.mean"),
     SL_gr = c("SL.glm", "SL.mean"),
     guard = c("Q", "g"),
